@@ -31,11 +31,7 @@ sub check_domains ( $self, $domains ) {
 
     my $res = P->http->get( $url, proxy => $self->{proxy} );
 
-    if ( !$res ) {
-        say dump $res;
-
-        return $res;
-    }
+    retun $res if !$res;
 
     my $data = P->data->from_xml( $res->{data} );
 
